@@ -1,5 +1,5 @@
 /*
-  netsed 1.2       (C) 2010-2012  Julien VdG <julien@silicone.homelinux.org>
+  netsed 1.3       (C) 2010-2019  Julien VdG <julien@silicone.homelinux.org>
   --------------------------------------------------------------------------
 
   This work is based on the original netsed:
@@ -126,7 +126,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 #endif
 
 /// Current version (recovered by Makefile for several release checks)
-#define VERSION "1.2"
+#define VERSION "1.3"
 /// max size for buffers
 #define MAX_BUF  100000
 
@@ -495,8 +495,9 @@ void parse_params(int argc,char* argv[]) {
   if (argc<optind+5) short_usage_hints("not enough parameters");
 
   // protocole
-  if (strcasecmp(argv[optind],"tcp")*strcasecmp(argv[optind],"udp")) short_usage_hints("incorrect protocol");
-  tcp = strncasecmp(argv[optind++], "udp", 3);
+  tcp = (strncasecmp(argv[optind], "tcp", 4) == 0)?1:0;
+  if ((strncasecmp(argv[optind], "udp", 4) != 0) && !tcp) short_usage_hints("incorrect protocol");
+  optind++;
 
   // local port
   lport = argv[optind++];
@@ -506,8 +507,8 @@ void parse_params(int argc,char* argv[]) {
   rport = argv[optind++];
 
   // allocate rule arrays, rule number is number of params after 5
-  rule=malloc((argc-optind)*sizeof(struct rule_s));
-  rule_live=malloc((argc-optind)*sizeof(int));
+  rule=calloc(argc-optind,sizeof(struct rule_s));
+  rule_live=calloc(argc-optind,sizeof(int));
   // parse rules
   for (i=optind;i<argc;i++) {
     char *fs=0, *ts=0, *cs=0;
